==> conkylayoutswitcher_0.0.3-1.tar.gz: conkylayoutswitcher-0.0.3/src/usr/lib/hildon-desktop/ConkyLayoutSwitcher.py <==
#!/bin/sh
import gtk
import hildondesktop
import os

def getTaskname():
    try:
#        time.sleep (.1)
        screen = gtk.gdk.screen_get_default()
        root = screen.get_root_window()
        #active_window = screen.get_active_window()
        x = root.property_get("_MB_CURRENT_APP_WINDOW")[2]
        num = int(''.join(map(str,x))) #http://stackoverflow.com/questions/489999/python-convert-list-of-ints-to-one-number
        #print "0x0%lx" % num
        active_window = gtk.gdk.window_foreign_new(num)

        #if not active_window is None:
        wmclass = active_window.property_get("WM_CLASS")[2].split('\x00')[0]
        return wmclass
    except:
        return ''


class ExampleStatusPlugin(hildondesktop.StatusMenuItem):
    def __init__(self):
        hildondesktop.StatusMenuItem.__init__(self)

        icon_theme = gtk.icon_theme_get_default()
      #  pixbuf = icon_theme.load_icon("general_email", 22, gtk.ICON_LOOKUP_NO_SVG)
     #   self.set_status_area_icon(pixbuf)

#        label = gtk.Label("Example")
        btn1 = gtk.Button()
        btn2 = gtk.Button()
        btn3 = gtk.Button()
        btn4 = gtk.Button()
        btni = gtk.Button()
        btn1.set_image(gtk.image_new_from_file("/usr/share/icons/hicolor/40x40/apps/conky-layout-switcher-1.png"))
        btn2.set_image(gtk.image_new_from_file("/usr/share/icons/hicolor/40x40/apps/conky-layout-switcher-2.png"))
        btn3.set_image(gtk.image_new_from_file("/usr/share/icons/hicolor/40x40/apps/conky-layout-switcher-3.png"))
        btn4.set_image(gtk.image_new_from_file("/usr/share/icons/hicolor/40x40/apps/conky-layout-switcher-4.png"))
        btni.set_image(gtk.image_new_from_file("/usr/share/icons/hicolor/40x40/apps/conky-layout-switcher-i.png"))


        btn1.connect("clicked", self.save1)

        btn2.connect("clicked", self.save2)

        btn3.connect("clicked", self.save3)

        btn4.connect("clicked", self.save4)
        btni.connect("clicked", self.info)


#        t = gtk.Table(5,1, False)
        box = gtk.HBox(False, 0)
#        self.add(t)     
#        t.attach(btn, 1,1,1,1)
#        t.attach(btnb)
#        self.add(label)
#        t.show()
        box.set_spacing(0)
        box.set_border_width(0)
        
#        self.add(btnb)
        self.add(box)
        box.pack_start(btn1, True, True, 1)
        box.pack_start(btn2, True, True, 1)
        box.pack_start(btn3, True, True, 1)
        box.pack_start(btn4, True, True, 1)
        box.pack_start(btni, True, True, 1)
        btn1.set_size_request(40,40)
        btn2.set_size_request(40,40)
        btn3.set_size_request(40,40)
        btn4.set_size_request(40,40)
        btni.set_size_request(16,40)

        self.show_all()

    def save1(self,widget,data=None):
        file = open('/home/user/.config/ConkyLayoutSwitcher/conky.layout', 'w')
        file.write('1')
        file.close()
        widget.get_toplevel().hide()
#        subprocess.call("conky", "")
        if getTaskname() != 'Conky':
            os.system("run-standalone.sh dbus-send --type=method_call --dest=com.nokia.HildonDesktop.AppMgr /com/nokia/HildonDesktop/AppMgr com.nokia.HildonDesktop.AppMgr.LaunchApplication string:conky")

    def save2(self,widget,data=None):
        file = open('/home/user/.config/ConkyLayoutSwitcher/conky.layout', 'w')
        file.write('2')
        file.close()
        widget.get_toplevel().hide()
        if getTaskname() != 'Conky':
            os.system("run-standalone.sh dbus-send --type=method_call --dest=com.nokia.HildonDesktop.AppMgr /com/nokia/HildonDesktop/AppMgr com.nokia.HildonDesktop.AppMgr.LaunchApplication string:conky")


    def save3(self,widget,data=None):
        file = open('/home/user/.config/ConkyLayoutSwitcher/conky.layout', 'w')
        file.write('3')
        file.close()
#        os.system("conky")        
        widget.get_toplevel().hide()
        if getTaskname() != 'Conky':
            os.system("run-standalone.sh dbus-send --type=method_call --dest=com.nokia.HildonDesktop.AppMgr /com/nokia/HildonDesktop/AppMgr com.nokia.HildonDesktop.AppMgr.LaunchApplication string:conky")

    def save4(self,widget,data=None):
        file = open('/home/user/.config/ConkyLayoutSwitcher/conky.layout', 'w')
        file.write('4')
        file.close()
#        gtk.Widget g = gtk.Widget.get_toplevel(widget)
#        gtk.widget r
#!        d = widget.get_toplevel()
#        gtk.widget.hide (d)
#!        d.hide()
        widget.get_toplevel().hide()
        if getTaskname() != 'Conky':
            os.system("run-standalone.sh dbus-send --type=method_call --dest=com.nokia.HildonDesktop.AppMgr /com/nokia/HildonDesktop/AppMgr com.nokia.HildonDesktop.AppMgr.LaunchApplication string:conky")

    def info(self,widget,data=None):
        widget.get_toplevel().hide()
#        mdlg = gtk.MessageDialog(None,0,gtk.MESSAGE_INFO,gtk.BUTTONS_OK,"Conky Layout Switcher")
#        mdlg.run()
#        mdlg.destroy()
#        os.system("/opt/usr/bin/ConkyLayoutSwitcher")
        if getTaskname() != 'ConkyLayoutSwitcher':
            os.system("run-standalone.sh dbus-send --type=method_call --dest=com.nokia.HildonDesktop.AppMgr /com/nokia/HildonDesktop/AppMgr com.nokia.HildonDesktop.AppMgr.LaunchApplication string:ConkyLayoutSwitcher")

hd_plugin_type = ExampleStatusPlugin

==> conkylayoutswitcher_0.0.7-1.tar.gz: conkylayoutswitcher-0.0.7/src/usr/lib/hildon-desktop/ConkyLayoutSwitcher.py <==
#!/bin/sh
import gtk
import hildondesktop
import os
import time

def getTaskname():
    try:
#        time.sleep (.1)
        screen = gtk.gdk.screen_get_default()
        root = screen.get_root_window()
        #active_window = screen.get_active_window()
        x = root.property_get("_MB_CURRENT_APP_WINDOW")[2]
        num = int(''.join(map(str,x))) #http://stackoverflow.com/questions/489999/python-convert-list-of-ints-to-one-number
        #print "0x0%lx" % num
        active_window = gtk.gdk.window_foreign_new(num)

        #if not active_window is None:
        wmclass = active_window.property_get("WM_CLASS")[2].split('\x00')[0]
        return wmclass
    except:
        return ''


class ConkyLayoutSwitcherStatusPlugin(hildondesktop.StatusMenuItem):
    def __init__(self):
        hildondesktop.StatusMenuItem.__init__(self)

        icon_theme = gtk.icon_theme_get_default()
      #  pixbuf = icon_theme.load_icon("general_email", 22, gtk.ICON_LOOKUP_NO_SVG)
     #   self.set_status_area_icon(pixbuf)

#        label = gtk.Label("Example")
        btn1 = gtk.Button()
        btn2 = gtk.Button()
        btn3 = gtk.Button()
        btn4 = gtk.Button()
        btni = gtk.Button()
        btn1.set_image(gtk.image_new_from_file("/usr/share/icons/hicolor/40x40/apps/conky-layout-switcher-1.png"))
        btn2.set_image(gtk.image_new_from_file("/usr/share/icons/hicolor/40x40/apps/conky-layout-switcher-2.png"))
        btn3.set_image(gtk.image_new_from_file("/usr/share/icons/hicolor/40x40/apps/conky-layout-switcher-3.png"))
        btn4.set_image(gtk.image_new_from_file("/usr/share/icons/hicolor/40x40/apps/conky-layout-switcher-4.png"))
        btni.set_image(gtk.image_new_from_file("/usr/share/icons/hicolor/40x40/apps/conky-layout-switcher-i.png"))


        btn1.connect("clicked", self.save1)

        btn2.connect("clicked", self.save2)

        btn3.connect("clicked", self.save3)

        btn4.connect("clicked", self.save4)
        btni.connect("clicked", self.info)


#        t = gtk.Table(5,1, False)
        box = gtk.HBox(False, 0)
#        self.add(t)     
#        t.attach(btn, 1,1,1,1)
#        t.attach(btnb)
#        self.add(label)
#        t.show()
        box.set_spacing(0)
        box.set_border_width(0)
#        box.connect("event", self.update)
        btn2.connect("event", self.update)
        btn3.connect("event", self.update)
        btn4.connect("event", self.update)
        
#        box.connect("map-event", self.update)
        
#        self.add(btnb)
        self.add(box)
        box.pack_start(btn1, True, True, 1)
        box.pack_start(btn2, True, True, 1)
        box.pack_start(btn3, True, True, 1)
        box.pack_start(btn4, True, True, 1)
        box.pack_start(btni, True, True, 1)
        btn1.set_size_request(40,40)
        btn2.set_size_request(40,40)
        btn3.set_size_request(40,40)
        btn4.set_size_request(40,40)
        btni.set_size_request(16,40)

        self.show_all()

    def update2(self,widget,data=None):
        ticks = " "
#        self.box.btn2.set_sensitive(False)
#        widget.set_sensitive(False)
#        self.box.btn2.set_sensitive(False)
        
    def update(self,widget,data=None):
        file = open('/home/user/.config/ConkyLayoutSwitcher/conkyLS.enabled', 'r')
        a = file.readline()
        file.close()
        if (a.find("1")!=-1):
            widget.set_sensitive(True)
        else:
            widget.set_sensitive(False)


#        widget.set_sensitive(False)
#        widget.set_sensitive(False)
#        self.set_sensitive(False)
#        ticks = str(time.time()) + widget.get_name() + "   " + str(data)
#        ticks = str(time.time()) + " " + a
     
           
#        file = open('/home/user/.config/ConkyLayoutSwitcher/conky.TEST', 'a')
#        file.write('Time:')
#        file.write(ticks)
#        file.write('\n')
#        file.close()
        
    
    def save1(self,widget,data=None):
        file = open('/home/user/.config/ConkyLayoutSwitcher/conky.layout', 'w')
        file.write('1')
        file.close()
        widget.get_toplevel().hide()
#        subprocess.call("conky", "")
        if getTaskname() != 'Conky':
            os.system("run-standalone.sh dbus-send --type=method_call --dest=com.nokia.HildonDesktop.AppMgr /com/nokia/HildonDesktop/AppMgr com.nokia.HildonDesktop.AppMgr.LaunchApplication string:conky")

    def save2(self,widget,data=None):
        file = open('/home/user/.config/ConkyLayoutSwitcher/conky.layout', 'w')
        file.write('2')
        file.close()
        widget.get_toplevel().hide()
        if getTaskname() != 'Conky':
            os.system("run-standalone.sh dbus-send --type=method_call --dest=com.nokia.HildonDesktop.AppMgr /com/nokia/HildonDesktop/AppMgr com.nokia.HildonDesktop.AppMgr.LaunchApplication string:conky")


    def save3(self,widget,data=None):
        file = open('/home/user/.config/ConkyLayoutSwitcher/conky.layout', 'w')
        file.write('3')
        file.close()
#        os.system("conky")        
        widget.get_toplevel().hide()
        if getTaskname() != 'Conky':
            os.system("run-standalone.sh dbus-send --type=method_call --dest=com.nokia.HildonDesktop.AppMgr /com/nokia/HildonDesktop/AppMgr com.nokia.HildonDesktop.AppMgr.LaunchApplication string:conky")

    def save4(self,widget,data=None):
        file = open('/home/user/.config/ConkyLayoutSwitcher/conky.layout', 'w')
        file.write('4')
        file.close()
#        gtk.Widget g = gtk.Widget.get_toplevel(widget)
#        gtk.widget r
#!        d = widget.get_toplevel()
#        gtk.widget.hide (d)
#!        d.hide()
        widget.get_toplevel().hide()
        if getTaskname() != 'Conky':
            os.system("run-standalone.sh dbus-send --type=method_call --dest=com.nokia.HildonDesktop.AppMgr /com/nokia/HildonDesktop/AppMgr com.nokia.HildonDesktop.AppMgr.LaunchApplication string:conky")

    def info(self,widget,data=None):
        widget.get_toplevel().hide()
#        mdlg = gtk.MessageDialog(None,0,gtk.MESSAGE_INFO,gtk.BUTTONS_OK,"Conky Layout Switcher")
#        mdlg.run()
#        mdlg.destroy()
#        os.system("/opt/usr/bin/ConkyLayoutSwitcher")
        if getTaskname() != 'ConkyLayoutSwitcher':
            os.system("run-standalone.sh dbus-send --type=method_call --dest=com.nokia.HildonDesktop.AppMgr /com/nokia/HildonDesktop/AppMgr com.nokia.HildonDesktop.AppMgr.LaunchApplication string:ConkyLayoutSwitcher")

hd_plugin_type = ConkyLayoutSwitcherStatusPlugin
